# Chunked Geometry Arrays

Chunked arrays of geospatial geometries, each of the same type.

- [`ChunkedPointArray`](#geoarrow.rust.core.ChunkedPointArray)
- [`ChunkedLineStringArray`](#geoarrow.rust.core.ChunkedLineStringArray)
- [`ChunkedPolygonArray`](#geoarrow.rust.core.ChunkedPolygonArray)
- [`ChunkedMultiPointArray`](#geoarrow.rust.core.ChunkedMultiPointArray)
- [`ChunkedMultiLineStringArray`](#geoarrow.rust.core.ChunkedMultiLineStringArray)
- [`ChunkedMultiPolygonArray`](#geoarrow.rust.core.ChunkedMultiPolygonArray)
- [`ChunkedMixedGeometryArray`](#geoarrow.rust.core.ChunkedMixedGeometryArray)
- [`ChunkedGeometryCollectionArray`](#geoarrow.rust.core.ChunkedGeometryCollectionArray)
- [`ChunkedWKBArray`](#geoarrow.rust.core.ChunkedWKBArray)
- [`ChunkedRectArray`](#geoarrow.rust.core.ChunkedRectArray)

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
        - "^__arrow"
      members:
        - ChunkedPointArray
        - ChunkedLineStringArray
        - ChunkedPolygonArray
        - ChunkedMultiPointArray
        - ChunkedMultiLineStringArray
        - ChunkedMultiPolygonArray
        - ChunkedMixedGeometryArray
        - ChunkedGeometryCollectionArray
        - ChunkedWKBArray
        - ChunkedRectArray
